import { Component, ChangeDetectionStrategy, ViewEncapsulation, forwardRef, Renderer2, ChangeDetectorRef, ViewChild, HostBinding, Input, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import { trigger, state, style, transition, animate } from '@angular/animations';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CheckboxComponent {
    /**
     * @param {?} _renderer
     * @param {?} _changeDetectorRef
     */
    constructor(_renderer, _changeDetectorRef) {
        this._renderer = _renderer;
        this._changeDetectorRef = _changeDetectorRef;
        /**
         * Input values to directly copy to inner checkbox
         */
        this.name = '';
        this.tabIndex = 0;
    }
    /**
     * @return {?}
     */
    get isFocused() {
        return this._focused;
    }
    /**
     * @return {?}
     */
    get checked() {
        return this.input.nativeElement.checked;
    }
    /**
     * @param {?} checked
     * @return {?}
     */
    set checked(checked) {
        this._renderer.setProperty(this.input.nativeElement, 'checked', checked);
    }
    // Focus Blur Handle
    /**
     * @return {?}
     */
    inputFocus() {
        this._focused = true;
    }
    /**
     * @return {?}
     */
    inputBlur() {
        this._focused = false;
        if (this._onTouchedCb) {
            this._onTouchedCb();
        }
    }
    /**
     * @param {?} value
     * @return {?}
     */
    writeValue(value) {
        this.checked = !!value;
        this._changeDetectorRef.markForCheck();
    }
    // tslint:disable-next-line:no-any
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnChange(fn) {
        this._onChangeCb = fn;
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnTouched(fn) {
        this._onTouchedCb = fn;
    }
    /**
     * @param {?} event
     * @return {?}
     */
    inputChange(event) {
        const { checked } = (/** @type {?} */ (event.target));
        if (this._onChangeCb) {
            this._onChangeCb(checked);
        }
    }
    /**
     * @return {?}
     */
    focus() {
        if (this.input && this.input.nativeElement) {
            this.input.nativeElement.focus();
        }
    }
}
CheckboxComponent.decorators = [
    { type: Component, args: [{
                selector: 'bm-checkbox',
                template: "<label class=\"bm-checkbox__label-container\">\n  <input\n    #input\n    type=\"checkbox\"\n    class=\"bm-visual-hidden\"\n    [checked]=\"checked\"\n    [required]=\"required\"\n    [disabled]=\"disabled\"\n    [name]=\"name\"\n    [tabIndex]=\"tabIndex\"\n    [readonly]=\"readonly\"\n    [attr.aria-label]=\"ariaLabel\"\n    [attr.aria-labelledby]=\"ariaLabelledby\"\n    (change)=\"inputChange($event)\"\n    (focus)=\"inputFocus()\"\n    (blur)=\"inputBlur()\"\n  />\n  <div class=\"bm-checkbox__container\">\n    <svg\n      *ngIf=\"checked\"\n      [@fadeInOut]=\"'in'\"\n      class=\"bm-checkbox__tick\"\n      xml:space=\"preserve\"\n      version=\"1.1\"\n      viewBox=\"0 0 24 24\"\n      xmlns=\"http://www.w3.org/2000/svg\"\n    >\n      <path\n        class=\"bm-checkbox__tick-path\"\n        d=\"M4.1,12.7 9,17.6 20.3,6.3\"\n        fill=\"none\"\n        stroke=\"white\"\n      ></path>\n    </svg>\n  </div>\n  <span class=\"bm-checkbox__label\"><ng-content></ng-content></span>\n</label>\n",
                changeDetection: ChangeDetectionStrategy.OnPush,
                encapsulation: ViewEncapsulation.None,
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        // tslint:disable-next-line:no-forward-ref
                        useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => CheckboxComponent)),
                        multi: true,
                    },
                ],
                animations: [
                    trigger('fadeInOut', [
                        state('in', style({ opacity: 1 })),
                        transition('void => *', [
                            style({
                                opacity: 0,
                            }),
                            animate('0.2s ease-in'),
                        ]),
                        transition('* => void', [
                            animate('0.2s ease-out', style({
                                opacity: 0,
                            })),
                        ]),
                    ]),
                ],
                styles: [".bm-checkbox--focused .bm-checkbox-container{border-color:var(--bm-checkbox-path-color,#4399fd)}.bm-checkbox__container{border:1px solid var(--secondary-color,#bcbcbc);border-radius:3px;display:inline-block;width:1em;height:1em;position:relative;vertical-align:middle}.bm-checkbox__tick{position:absolute}.bm-checkbox__tick-path{stroke:var(--bm-checkbox-path-color,#4399fd);stroke-width:5px;vertical-align:middle}"]
            }] }
];
/** @nocollapse */
CheckboxComponent.ctorParameters = () => [
    { type: Renderer2 },
    { type: ChangeDetectorRef }
];
CheckboxComponent.propDecorators = {
    input: [{ type: ViewChild, args: ['input', { static: true },] }],
    isFocused: [{ type: HostBinding, args: ['class.bm-checkbox--focused',] }],
    name: [{ type: Input }],
    tabIndex: [{ type: Input }],
    required: [{ type: Input }],
    disabled: [{ type: Input }],
    readonly: [{ type: Input }],
    ariaLabel: [{ type: Input, args: ['aria-label',] }],
    ariaLabelledby: [{ type: Input, args: ['aria-labelledby',] }],
    checked: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CheckboxComponentModule {
}
CheckboxComponentModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [CheckboxComponent],
                exports: [CheckboxComponent],
            },] }
];

export { CheckboxComponent, CheckboxComponentModule };
//# sourceMappingURL=bmat-angular-forms-bm-checkbox.js.map
