import { trigger, state, style, transition, animate } from '@angular/animations';
import { Component, ViewEncapsulation, forwardRef, Renderer2, ViewChild, HostBinding, Input, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class BMRadioComponent {
    /**
     * @param {?} _renderer
     */
    constructor(_renderer) {
        this._renderer = _renderer;
        /**
         * Input values to directly copy to inner radio
         */
        this.name = '';
        this.value = '';
        this.tabIndex = 0;
    }
    /**
     * @return {?}
     */
    get isFocused() {
        return this._focused;
    }
    /**
     * @param {?} checked
     * @return {?}
     */
    set checked(checked) {
        if (checked !== this.checked) {
            this._renderer.setProperty(this.input.nativeElement, 'checked', checked);
        }
    }
    /**
     * @return {?}
     */
    get checked() {
        return this.input.nativeElement.checked;
    }
    /**
     * @return {?}
     */
    inputFocus() {
        this._focused = true;
    }
    /**
     * @return {?}
     */
    inputBlur() {
        this._focused = false;
        if (this._onTouchedCb) {
            this._onTouchedCb();
        }
    }
    // tslint:disable-next-line:no-any
    /**
     * @param {?} value
     * @return {?}
     */
    writeValue(value) {
        this.checked = value === this.value;
    }
    // tslint:disable-next-line:no-any
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnChange(fn) {
        this._onChangeCb = fn;
    }
    // tslint:disable-next-line:no-any
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnTouched(fn) {
        this._onTouchedCb = fn;
    }
    /**
     * @return {?}
     */
    inputChange() {
        if (this._onChangeCb && this.checked) {
            this._onChangeCb(this.value);
        }
    }
    /**
     * @return {?}
     */
    focus() {
        this.input.nativeElement.focus();
    }
}
BMRadioComponent.decorators = [
    { type: Component, args: [{
                selector: 'bm-radio',
                template: "<label class=\"bm-radio__label_container\">\n  <input\n    (blur)=\"inputBlur()\"\n    (change)=\"inputChange()\"\n    (focus)=\"inputFocus()\"\n    [attr.aria-label]=\"ariaLabel\"\n    [attr.aria-labelledby]=\"ariaLabelledby\"\n    [disabled]=\"disabled\"\n    [name]=\"name\"\n    [readonly]=\"readonly\"\n    [required]=\"required\"\n    [tabIndex]=\"tabIndex\"\n    #input\n    class=\"bm-visual-hidden\"\n    type=\"radio\"\n  />\n  <div class=\"bm-radio__container\">\n    <span class=\"bm-radio__checked-mark\" *ngIf=\"checked\" [@fadeInOut]=\"'in'\">\n    </span>\n  </div>\n  <span class=\"bm-radio__label\"><ng-content></ng-content></span>\n</label>\n",
                encapsulation: ViewEncapsulation.None,
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        // tslint:disable-next-line:no-forward-ref
                        useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => BMRadioComponent)),
                        multi: true,
                    },
                ],
                animations: [
                    trigger('fadeInOut', [
                        state('in', style({ opacity: 1 })),
                        transition('void => *', [
                            style({
                                opacity: 0,
                            }),
                            animate('0.2s ease-in'),
                        ]),
                        transition('* => void', [
                            animate('0.2s ease-out', style({
                                opacity: 0,
                            })),
                        ]),
                    ]),
                ],
                styles: [".bm-radio--focused .bm-radio-container{border-color:var(--bm-checkbox-path-color,#4399fd)}.bm-radio__container{border:1px solid var(--secondary-color-hover,#959494);border-radius:50%;display:inline-block;width:1em;height:1em;position:relative;text-align:center;vertical-align:middle}.bm-radio__checked-mark{background-color:var(--bm-checkbox-path-color,#4399fd);box-sizing:border-box;border:2px solid #fff;border-radius:50%;width:100%;height:100%;display:block}"]
            }] }
];
/** @nocollapse */
BMRadioComponent.ctorParameters = () => [
    { type: Renderer2 }
];
BMRadioComponent.propDecorators = {
    input: [{ type: ViewChild, args: ['input', { static: true },] }],
    isFocused: [{ type: HostBinding, args: ['class.bm-radio--focused',] }],
    name: [{ type: Input }],
    value: [{ type: Input }],
    tabIndex: [{ type: Input }],
    required: [{ type: Input }],
    disabled: [{ type: Input }],
    readonly: [{ type: Input }],
    ariaLabel: [{ type: Input, args: ['aria-label',] }],
    ariaLabelledby: [{ type: Input, args: ['aria-labelledby',] }],
    checked: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class BMRadioComponentModule {
}
BMRadioComponentModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [BMRadioComponent],
                exports: [BMRadioComponent],
            },] }
];

export { BMRadioComponent, BMRadioComponentModule };
//# sourceMappingURL=bmat-angular-forms-bm-radio.js.map
