import { EventEmitter, Component, ChangeDetectionStrategy, ViewEncapsulation, forwardRef, ChangeDetectorRef, Renderer2, ViewChild, HostBinding, Input, Output, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class BMSwitchCheckboxComponent {
    /**
     * @param {?} _changeDetectorRef
     * @param {?} _renderer
     */
    constructor(_changeDetectorRef, _renderer) {
        this._changeDetectorRef = _changeDetectorRef;
        this._renderer = _renderer;
        this.tabIndex = 0;
        this.switchChange = new EventEmitter();
    }
    /**
     * @return {?}
     */
    get isFocused() {
        return this._focused;
    }
    /**
     * @param {?} checked
     * @return {?}
     */
    set checked(checked) {
        this._renderer.setProperty(this.input.nativeElement, 'checked', checked);
    }
    /**
     * @return {?}
     */
    get checked() {
        if (this.input && this.input.nativeElement) {
            return this.input.nativeElement.checked;
        }
        return false;
    }
    // Focus Blur Handle
    /**
     * @return {?}
     */
    inputFocus() {
        this._focused = true;
    }
    /**
     * @return {?}
     */
    inputBlur() {
        this._focused = false;
        if (this._onTouched) {
            this._onTouched();
        }
    }
    /**
     * @param {?} value
     * @return {?}
     */
    writeValue(value) {
        this.checked = value;
        this._changeDetectorRef.markForCheck();
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnChange(fn) {
        this._propagateChange = fn;
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnTouched(fn) {
        this._onTouched = fn;
    }
    /**
     * @param {?} isDisabled
     * @return {?}
     */
    setDisabledState(isDisabled) {
        this.disabled = isDisabled;
        this._changeDetectorRef.markForCheck();
    }
    /**
     * @param {?} event
     * @return {?}
     */
    inputChange(event) {
        if (this._propagateChange) {
            this._propagateChange(((/** @type {?} */ (event.target))).checked);
        }
        this.switchChange.emit({
            checked: ((/** @type {?} */ (event.target))).checked,
            source: this,
        });
    }
    /**
     * @return {?}
     */
    focus() {
        if (this.input && this.input.nativeElement) {
            this.input.nativeElement.focus();
        }
    }
}
BMSwitchCheckboxComponent.decorators = [
    { type: Component, args: [{
                selector: 'bm-switch-checkbox',
                template: "<label class=\"bm-switch-checkbox__label-container\">\n  <input\n    #input\n    type=\"checkbox\"\n    class=\"bm-switch-checkbox__checkbox\"\n    (blur)=\"inputBlur()\"\n    (change)=\"inputChange($event)\"\n    (focus)=\"inputFocus()\"\n    [attr.aria-label]=\"ariaLabel\"\n    [attr.aria-labelledby]=\"ariaLabelledby\"\n    [disabled]=\"disabled\"\n    [name]=\"name\"\n    [readonly]=\"readonly\"\n    [required]=\"required\"\n    [tabIndex]=\"tabIndex\"\n  />\n  <span\n    class=\"bm-switch-checkbox__container\"\n    [ngClass]=\"{\n      'bm-switch-checkbox__container--checked': checked,\n      'bm-switch-checkbox__container--disabled': disabled\n    }\"\n  >\n    <span\n      class=\"bm-switch-checkbox__thumb\"\n      [ngClass]=\"{ 'bm-switch-checkbox__thumb--checked': checked }\"\n    ></span>\n  </span>\n  <span class=\"bm-switch-checkbox__label\"><ng-content></ng-content></span>\n</label>\n",
                changeDetection: ChangeDetectionStrategy.OnPush,
                encapsulation: ViewEncapsulation.None,
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        // tslint:disable-next-line:no-forward-ref
                        useExisting: forwardRef((/**
                         * @return {?}
                         */
                        () => BMSwitchCheckboxComponent)),
                        multi: true,
                    },
                ],
                styles: ["bm-switch-checkbox{border:1px solid transparent;border-radius:.2em;display:inline-block}.bm-switch-checkbox__checkbox{border:0;clip:rect(0 0 0 0);height:1px;margin:-1px;overflow:hidden;padding:0;position:absolute;text-transform:none;width:1px}.bm-switch-checkbox--focused,.bm-switch-checkbox--focused .bm-switch-checkbox-container{border-color:var(--anchor-color,#4399fd)}.bm-switch-checkbox__container{align-items:center;background-color:var(--bm-switch-unchecked-color,#dadfea);border-color:var(--bm-switch-unchecked-color,#dadfea);border-radius:.2em;border:1px solid var(--secondary-color,#dadfea);display:inline-flex;height:1.5em;overflow:hidden;position:relative;transition:.2s ease-in;vertical-align:middle;width:3em}.bm-switch-checkbox__container--checked{background-color:var(--bm-switch-checked-color,#4dbd74);border-color:var(--bm-switch-checked-border-color,#3a9d5d)}.bm-switch-checkbox__container--disabled{opacity:.6;cursor:not-allowed}.bm-switch-checkbox__thumb{background-color:#fff;border-radius:.2em;border:1px solid var(--secondary-color,#bcbcbc);bottom:.1em;display:inline-block;margin:0 .1em;position:absolute;top:.1em;-webkit-transform:translateX(0);transform:translateX(0);transition:transform .2s ease-in;transition:transform .2s ease-in,-webkit-transform .2s ease-in;vertical-align:middle;width:calc(1.5em - .2em)}.bm-switch-checkbox__thumb::after,.bm-switch-checkbox__thumb::before{align-items:center;bottom:0;display:flex;font-size:.6em;font-weight:600;position:absolute;top:0}.bm-switch-checkbox__thumb::before{color:#fff;content:var(--switch-checked-label, \"Y\");left:-1.6em}.bm-switch-checkbox__thumb::after{color:#80838a;content:var(--switch-unchecked-label, \"N\");right:-1.6em}.bm-switch-checkbox__thumb--checked{border-color:var(--bm-switch-checked-border-color,#3a9d5d);-webkit-transform:translateX(100%);transform:translateX(100%)}.bm-switch-checkbox__tick-path{stroke:var(--bm-checkbox-path-color,#4399fd);stroke-width:.2em;vertical-align:middle}"]
            }] }
];
/** @nocollapse */
BMSwitchCheckboxComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: Renderer2 }
];
BMSwitchCheckboxComponent.propDecorators = {
    input: [{ type: ViewChild, args: ['input', { static: true },] }],
    isFocused: [{ type: HostBinding, args: ['class.bm-switch-checkbox--focused',] }],
    ariaLabel: [{ type: Input, args: ['aria-label',] }],
    ariaLabelledby: [{ type: Input, args: ['aria-labelledby',] }],
    disabled: [{ type: Input }],
    name: [{ type: Input }],
    readonly: [{ type: Input }],
    required: [{ type: Input }],
    tabIndex: [{ type: Input }],
    checked: [{ type: Input }],
    switchChange: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * Module of the Switch Component
 */
class BMSwitchCheckboxModule {
}
BMSwitchCheckboxModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [BMSwitchCheckboxComponent],
                exports: [BMSwitchCheckboxComponent],
            },] }
];

export { BMSwitchCheckboxComponent, BMSwitchCheckboxModule };
//# sourceMappingURL=bmat-angular-forms-bm-switch-checkbox.js.map
