import { Injectable, Directive, ElementRef, Input, HostListener, HostBinding, Component, forwardRef, ChangeDetectionStrategy, ViewEncapsulation, Output, EventEmitter, ViewChild, NgModule } from '@angular/core';
import { __values, __assign } from 'tslib';
import { Observable, combineLatest, of, Subject, Subscription } from 'rxjs';
import { switchMap } from 'rxjs/operators';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var UploadEventsService = /** @class */ (function () {
    function UploadEventsService() {
        var _this = this;
        this._uploads$ = new Subject();
        this.events$ = this._uploads$.pipe(switchMap((/**
         * @param {?} obs
         * @return {?}
         */
        function (obs) { return _this.mergeIndividualUploads(obs); })));
    }
    // tslint:disable-next-line:max-func-body-length
    // tslint:disable-next-line:max-func-body-length
    /**
     * @param {?} fileList
     * @param {?=} dataType
     * @return {?}
     */
    UploadEventsService.prototype.readFiles = 
    // tslint:disable-next-line:max-func-body-length
    /**
     * @param {?} fileList
     * @param {?=} dataType
     * @return {?}
     */
    function (fileList, dataType) {
        if (dataType === void 0) { dataType = 3 /* None */; }
        /** @type {?} */
        var fileObservables = [];
        if (fileList) {
            // tslint:disable-next-line:prefer-for-of
            for (var i = 0; i < fileList.length; i += 1) {
                fileObservables.push(this.fileReaderObsFactory(fileList[i], dataType));
            }
        }
        this._uploads$.next(fileObservables);
    };
    /**
     * @private
     * @param {?} obs
     * @return {?}
     */
    UploadEventsService.prototype.mergeIndividualUploads = /**
     * @private
     * @param {?} obs
     * @return {?}
     */
    function (obs) {
        return new Observable((/**
         * @param {?} observer
         * @return {?}
         */
        function (observer) {
            /** @type {?} */
            var subs = combineLatest(obs).subscribe({
                next: (/**
                 * @param {?} events
                 * @return {?}
                 */
                function (events) {
                    var e_1, _a, e_2, _b;
                    /** @type {?} */
                    var aborted = false;
                    /** @type {?} */
                    var completedCount = 0;
                    /** @type {?} */
                    var next = {
                        files: events,
                        status: 0 /* EMPTY */,
                        error: null,
                    };
                    try {
                        eventLoop: for (var events_1 = __values(events), events_1_1 = events_1.next(); !events_1_1.done; events_1_1 = events_1.next()) {
                            var event_1 = events_1_1.value;
                            switch (event_1.status) {
                                case 4 /* ABORT */:
                                    next.status = 4 /* ABORT */;
                                    aborted = true;
                                    break eventLoop;
                                case 1 /* LOADING */:
                                    next.status = 1 /* LOADING */;
                                    break;
                                case 2 /* DONE */:
                                    completedCount += 1;
                                    break;
                                default:
                            }
                        }
                    }
                    catch (e_1_1) { e_1 = { error: e_1_1 }; }
                    finally {
                        try {
                            if (events_1_1 && !events_1_1.done && (_a = events_1.return)) _a.call(events_1);
                        }
                        finally { if (e_1) throw e_1.error; }
                    }
                    if (aborted) {
                        try {
                            for (var events_2 = __values(events), events_2_1 = events_2.next(); !events_2_1.done; events_2_1 = events_2.next()) {
                                var event_2 = events_2_1.value;
                                if (event_2.reader) {
                                    event_2.reader.abort();
                                }
                            }
                        }
                        catch (e_2_1) { e_2 = { error: e_2_1 }; }
                        finally {
                            try {
                                if (events_2_1 && !events_2_1.done && (_b = events_2.return)) _b.call(events_2);
                            }
                            finally { if (e_2) throw e_2.error; }
                        }
                    }
                    else if (completedCount === events.length) {
                        next.status = 2 /* DONE */;
                    }
                    observer.next(next);
                }),
                complete: (/**
                 * @return {?}
                 */
                function () { return observer.complete(); }),
                error: (/**
                 * @param {?} err
                 * @return {?}
                 */
                function (err) { return observer.error(err); }),
            });
            return (/**
             * @return {?}
             */
            function () {
                subs.unsubscribe();
            });
        }));
    };
    // tslint:disable-next-line:max-func-body-length
    // tslint:disable-next-line:max-func-body-length
    /**
     * @private
     * @param {?} file
     * @param {?} dataType
     * @return {?}
     */
    UploadEventsService.prototype.fileReaderObsFactory = 
    // tslint:disable-next-line:max-func-body-length
    /**
     * @private
     * @param {?} file
     * @param {?} dataType
     * @return {?}
     */
    function (file, dataType) {
        var _this = this;
        /** @type {?} */
        var fileData = {
            name: file.name,
            size: file.size,
            type: file.type,
            data: null,
            lastModified: file.lastModified,
            total: file.size,
            loaded: 0,
        };
        if (dataType === 3 /* None */) {
            fileData.data = file;
            return of(this.eventFactory(fileData, 2 /* DONE */, null));
        }
        // tslint:disable-next-line:max-func-body-length
        return new Observable((/**
         * @param {?} observer
         * @return {?}
         */
        function (observer) {
            /** @type {?} */
            var completed = false;
            /** @type {?} */
            var reader = new FileReader();
            reader.addEventListener('error', (/**
             * @return {?}
             */
            function () {
                observer.error(_this.eventFactory(fileData, 3 /* ERROR */, reader));
                completed = true;
                observer.complete();
            }), { once: true });
            reader.addEventListener('abort', (/**
             * @return {?}
             */
            function () {
                observer.next(_this.eventFactory(fileData, 4 /* ABORT */, reader));
                completed = true;
                observer.complete();
            }), { once: true });
            /** @type {?} */
            var onprogress = (/**
             * @param {?} e
             * @return {?}
             */
            function (e) {
                if (e.lengthComputable) {
                    fileData.total = e.total;
                    fileData.loaded = e.loaded;
                }
                observer.next(_this.eventFactory(fileData, 1 /* LOADING */, reader));
            });
            reader.addEventListener('loadstart', (/**
             * @return {?}
             */
            function () {
                observer.next(_this.eventFactory(fileData, 1 /* LOADING */, reader));
            }), { once: true });
            reader.addEventListener('load', (/**
             * @return {?}
             */
            function () {
                fileData.loaded = (/** @type {?} */ (fileData.size));
                fileData.data = reader.result;
                observer.next(_this.eventFactory(fileData, 2 /* DONE */, reader));
                completed = true;
                observer.complete();
            }));
            switch (dataType) {
                case 0 /* ArrayBuffer */:
                    reader.readAsArrayBuffer(file);
                    break;
                case 1 /* DataURL */:
                    reader.readAsDataURL(file);
                    break;
                case 2 /* Text */:
                    reader.readAsText(file);
                    break;
                default:
                    observer.error(new TypeError('Invalid output type: Select ArrayBuffer, DataURL or Text'));
                    completed = true;
                    observer.complete();
                    return;
            }
            return (/**
             * @return {?}
             */
            function () {
                if (reader) {
                    if (!completed) {
                        reader.abort();
                    }
                    if (onprogress) {
                        reader.removeEventListener('progress', onprogress);
                    }
                }
            });
        }));
    };
    /**
     * @private
     * @param {?} file
     * @param {?} status
     * @param {?=} reader
     * @return {?}
     */
    UploadEventsService.prototype.eventFactory = /**
     * @private
     * @param {?} file
     * @param {?} status
     * @param {?=} reader
     * @return {?}
     */
    function (file, status, reader) {
        if (reader === void 0) { reader = null; }
        return {
            status: status,
            reader: reader,
            file: __assign({}, file),
        };
    };
    UploadEventsService.decorators = [
        { type: Injectable }
    ];
    /** @nocollapse */
    UploadEventsService.ctorParameters = function () { return []; };
    return UploadEventsService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var FileUploadDirective = /** @class */ (function () {
    function FileUploadDirective(_elementRef, _uploadEventsService) {
        this._elementRef = _elementRef;
        this._uploadEventsService = _uploadEventsService;
    }
    /**
     * @param {?} e
     * @return {?}
     */
    FileUploadDirective.prototype.onInputChange = /**
     * @param {?} e
     * @return {?}
     */
    function (e) {
        e.preventDefault();
        /** @type {?} */
        var next = this._elementRef.nativeElement.files &&
            this._elementRef.nativeElement.files.length
            ? this._elementRef.nativeElement.files
            : null;
        this._uploadEventsService.readFiles(next, this.dataType);
    };
    FileUploadDirective.decorators = [
        { type: Directive, args: [{
                    selector: 'input[bmFileUpload]',
                },] }
    ];
    /** @nocollapse */
    FileUploadDirective.ctorParameters = function () { return [
        { type: ElementRef },
        { type: UploadEventsService }
    ]; };
    FileUploadDirective.propDecorators = {
        dataType: [{ type: Input }],
        onInputChange: [{ type: HostListener, args: ['change', ['$event'],] }]
    };
    return FileUploadDirective;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var FileUploadDraggableDirective = /** @class */ (function () {
    function FileUploadDraggableDirective(_uploadEventsService) {
        this._uploadEventsService = _uploadEventsService;
    }
    /**
     * @param {?} event
     * @return {?}
     */
    FileUploadDraggableDirective.prototype.ondragover = /**
     * @param {?} event
     * @return {?}
     */
    function (event) {
        if (!this.disabled) {
            event.preventDefault();
            this.dragHover = true;
        }
    };
    /**
     * @return {?}
     */
    FileUploadDraggableDirective.prototype.ondragleave = /**
     * @return {?}
     */
    function () {
        this.dragHover = false;
    };
    /**
     * @param {?} event
     * @return {?}
     */
    FileUploadDraggableDirective.prototype.ondrop = /**
     * @param {?} event
     * @return {?}
     */
    function (event) {
        var dataTransfer = event.dataTransfer;
        if (!this.disabled && dataTransfer) {
            dataTransfer.dropEffect = 'copy';
            this._uploadEventsService.readFiles(dataTransfer.files, this.dataType);
            event.preventDefault();
        }
    };
    FileUploadDraggableDirective.decorators = [
        { type: Directive, args: [{ selector: '[bmFileUploadDraggable]' },] }
    ];
    /** @nocollapse */
    FileUploadDraggableDirective.ctorParameters = function () { return [
        { type: UploadEventsService }
    ]; };
    FileUploadDraggableDirective.propDecorators = {
        disabled: [{ type: Input }],
        dataType: [{ type: Input }],
        dragHover: [{ type: HostBinding, args: ['class.drag-hover',] }],
        ondragover: [{ type: HostListener, args: ['dragover', ['$event'],] }],
        ondragleave: [{ type: HostListener, args: ['dragleave',] }],
        ondrop: [{ type: HostListener, args: ['drop', ['$event'],] }]
    };
    return FileUploadDraggableDirective;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var BMFileUploaderComponent = /** @class */ (function () {
    function BMFileUploaderComponent(_uploadEventsService) {
        this._uploadEventsService = _uploadEventsService;
        this.abort = new EventEmitter();
        this.done = new EventEmitter();
        this.empty = new EventEmitter();
        this.error = new EventEmitter();
        this.loading = new EventEmitter();
        this.multipleInt = 0;
        this._subs = Subscription.EMPTY;
    }
    Object.defineProperty(BMFileUploaderComponent.prototype, "multiple", {
        get: /**
         * @return {?}
         */
        function () {
            return this.multipleInt === 1;
        },
        set: /**
         * @param {?} v
         * @return {?}
         */
        function (v) {
            this.multipleInt = v ? 1 : 0;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @return {?}
     */
    BMFileUploaderComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
        var _this = this;
        this._uploadEventsService.events$.subscribe({
            // tslint:disable-next-line:cyclomatic-complexity
            next: (/**
             * @param {?} event
             * @return {?}
             */
            function (event) {
                switch (event.status) {
                    case 4 /* ABORT */:
                        _this.abort.emit(event);
                        if (_this._onChangeCb) {
                            _this._onChangeCb([]);
                        }
                        break;
                    case 2 /* DONE */:
                        _this.done.emit(event);
                        if (_this._onChangeCb) {
                            _this._onChangeCb(event.files.map((/**
                             * @param {?} e
                             * @return {?}
                             */
                            function (e) { return e.file; })));
                        }
                        break;
                    case 0 /* EMPTY */:
                        _this.empty.emit(event);
                        if (_this._onChangeCb) {
                            _this._onChangeCb([]);
                        }
                        break;
                    case 3 /* ERROR */:
                        _this.error.emit(event);
                        if (_this._onChangeCb) {
                            _this._onChangeCb([]);
                        }
                        break;
                    case 1 /* LOADING */:
                        _this.loading.emit(event);
                        if (_this._onTouchedCb) {
                            _this._onTouchedCb();
                        }
                        break;
                    default:
                }
            }),
        });
    };
    /**
     * @return {?}
     */
    BMFileUploaderComponent.prototype.ngOnDestroy = /**
     * @return {?}
     */
    function () {
        this._subs.unsubscribe();
    };
    /**
     * @return {?}
     */
    BMFileUploaderComponent.prototype.onFocusin = /**
     * @return {?}
     */
    function () {
        if (this._onTouchedCb) {
            this._onTouchedCb();
        }
    };
    /**
     * @param {?} val
     * @return {?}
     */
    BMFileUploaderComponent.prototype.writeValue = /**
     * @param {?} val
     * @return {?}
     */
    function (val) {
        if (val instanceof FileList) {
            this._uploadEventsService.readFiles(val, this.dataType);
        }
        else {
            this._uploadEventsService.readFiles(null, this.dataType);
        }
    };
    /**
     * @param {?} fn
     * @return {?}
     */
    BMFileUploaderComponent.prototype.registerOnChange = /**
     * @param {?} fn
     * @return {?}
     */
    function (fn) {
        this._onChangeCb = fn;
    };
    /**
     * @param {?} fn
     * @return {?}
     */
    BMFileUploaderComponent.prototype.registerOnTouched = /**
     * @param {?} fn
     * @return {?}
     */
    function (fn) {
        this._onTouchedCb = fn;
    };
    /**
     * @param {?} isDisabled
     * @return {?}
     */
    BMFileUploaderComponent.prototype.setDisabledState = /**
     * @param {?} isDisabled
     * @return {?}
     */
    function (isDisabled) {
        this.disabled = isDisabled;
    };
    BMFileUploaderComponent.decorators = [
        { type: Component, args: [{
                    selector: 'bm-file-upload',
                    template: "<input\n  [accept]=\"accept\"\n  [dataType]=\"dataType\"\n  [disabled]=\"disabled\"\n  [multiple]=\"multiple\"\n  #inputFile\n  bmFileUpload\n  class=\"bm-visual-hidden\"\n  tabindex=\"-1\"\n  type=\"file\"\n/>\n<div\n  [dataType]=\"dataType\"\n  [disabled]=\"disabled\"\n  bmFileUploadDraggable\n  class=\"bm-file-upload-drop-area\"\n>\n  <ng-content></ng-content>\n  <div>\n    <i class=\"fas fa-upload bm-file-upload__upload-icon\" aria-hidden=\"true\"></i>\n    <div>\n      <p i18n>\n        Drag &amp; Drop your audio {multipleInt, plural, =0 {file} =1 {files}}\n      </p>\n      <p>\n        <button\n          (click)=\"inputFile.click()\"\n          (focusin)=\"onFocusin()\"\n          [disabled]=\"disabled\"\n          class=\"bm-button bm-button--primary\"\n          type=\"button\"\n          i18n=\"Select files|Text in the button inside the draggable area of the file-uploader\"\n        >\n          Select {multipleInt, plural, =0 {file} =1 {files}}\n        </button>\n      </p>\n    </div>\n  </div>\n  <ng-content select=\"[bmFileUploadFooter]\"></ng-content>\n</div>\n",
                    providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            // tslint:disable-next-line:no-forward-ref
                            useExisting: forwardRef((/**
                             * @return {?}
                             */
                            function () { return BMFileUploaderComponent; })),
                            multi: true,
                        },
                        UploadEventsService,
                    ],
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    // tslint:disable-next-line:use-component-view-encapsulation
                    encapsulation: ViewEncapsulation.None,
                    styles: [".bm-file-upload--drag-hover .bm-file-upload-drop-area{border-width:2px}.bm-file-upload__upload-icon{font-size:3em}.bm-file-upload-drop-area{box-sizing:border-box;border:1px dashed var(--header-background-color,#3e71ad);border-radius:3px;display:flex;flex-direction:column;justify-content:center;align-items:center;text-align:center;padding:1em}.bm-file-upload-drop-area p{font-size:.9rem;margin:.5rem 0}.bm-file-upload-drop-area *{pointer-events:none}.bm-file-upload-drop-area button{pointer-events:auto}"]
                }] }
    ];
    /** @nocollapse */
    BMFileUploaderComponent.ctorParameters = function () { return [
        { type: UploadEventsService }
    ]; };
    BMFileUploaderComponent.propDecorators = {
        accept: [{ type: Input }],
        dataType: [{ type: Input }],
        disabled: [{ type: Input }],
        multiple: [{ type: Input }],
        abort: [{ type: Output }],
        done: [{ type: Output }],
        empty: [{ type: Output }],
        error: [{ type: Output }],
        loading: [{ type: Output }]
    };
    return BMFileUploaderComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var BMClickFileUploaderComponent = /** @class */ (function () {
    function BMClickFileUploaderComponent(_uploadEventsService) {
        this._uploadEventsService = _uploadEventsService;
        this.abort = new EventEmitter();
        this.done = new EventEmitter();
        this.empty = new EventEmitter();
        this.error = new EventEmitter();
        this.loading = new EventEmitter();
        this._subs = Subscription.EMPTY;
    }
    /**
     * @return {?}
     */
    BMClickFileUploaderComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
        var _this = this;
        this._uploadEventsService.events$.subscribe({
            // tslint:disable-next-line:cyclomatic-complexity
            next: (/**
             * @param {?} event
             * @return {?}
             */
            function (event) {
                switch (event.status) {
                    case 4 /* ABORT */:
                        _this.abort.emit(event);
                        if (_this._onChangeCb) {
                            _this._onChangeCb([]);
                        }
                        break;
                    case 2 /* DONE */:
                        _this.done.emit(event);
                        if (_this._onChangeCb) {
                            _this._onChangeCb(event.files.map((/**
                             * @param {?} e
                             * @return {?}
                             */
                            function (e) { return e.file; })));
                        }
                        break;
                    case 0 /* EMPTY */:
                        _this.empty.emit(event);
                        if (_this._onChangeCb) {
                            _this._onChangeCb([]);
                        }
                        break;
                    case 3 /* ERROR */:
                        _this.error.emit(event);
                        if (_this._onChangeCb) {
                            _this._onChangeCb([]);
                        }
                        break;
                    case 1 /* LOADING */:
                        _this.loading.emit(event);
                        if (_this._onTouchedCb) {
                            _this._onTouchedCb();
                        }
                        break;
                    default:
                }
            }),
        });
    };
    /**
     * @return {?}
     */
    BMClickFileUploaderComponent.prototype.ngOnDestroy = /**
     * @return {?}
     */
    function () {
        this._subs.unsubscribe();
    };
    /**
     * @return {?}
     */
    BMClickFileUploaderComponent.prototype.onFocusin = /**
     * @return {?}
     */
    function () {
        if (this._onTouchedCb) {
            this._onTouchedCb();
        }
    };
    /**
     * @param {?} val
     * @return {?}
     */
    BMClickFileUploaderComponent.prototype.writeValue = /**
     * @param {?} val
     * @return {?}
     */
    function (val) {
        if (val instanceof FileList) {
            this._uploadEventsService.readFiles(val, this.dataType);
        }
        else {
            this._inputElement.nativeElement.value = '';
            this._uploadEventsService.readFiles(null, this.dataType);
        }
    };
    /**
     * @param {?} fn
     * @return {?}
     */
    BMClickFileUploaderComponent.prototype.registerOnChange = /**
     * @param {?} fn
     * @return {?}
     */
    function (fn) {
        this._onChangeCb = fn;
    };
    /**
     * @param {?} fn
     * @return {?}
     */
    BMClickFileUploaderComponent.prototype.registerOnTouched = /**
     * @param {?} fn
     * @return {?}
     */
    function (fn) {
        this._onTouchedCb = fn;
    };
    /**
     * @param {?} isDisabled
     * @return {?}
     */
    BMClickFileUploaderComponent.prototype.setDisabledState = /**
     * @param {?} isDisabled
     * @return {?}
     */
    function (isDisabled) {
        this.disabled = isDisabled;
    };
    BMClickFileUploaderComponent.decorators = [
        { type: Component, args: [{
                    selector: 'bm-click-file-upload',
                    template: "<input\n  [accept]=\"accept\"\n  [dataType]=\"dataType\"\n  [disabled]=\"disabled\"\n  [multiple]=\"multiple\"\n  #inputFile\n  bmFileUpload\n  class=\"bm-visual-hidden\"\n  tabindex=\"-1\"\n  type=\"file\"\n/>\n<button\n  (click)=\"inputFile.click()\"\n  (focusin)=\"onFocusin()\"\n  [dataType]=\"dataType\"\n  [disabled]=\"disabled\"\n  bmFileUploadDraggable\n  class=\"bm-click-file-upload-drop-area\"\n>\n  <ng-content></ng-content>\n</button>\n",
                    providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            // tslint:disable-next-line:no-forward-ref
                            useExisting: forwardRef((/**
                             * @return {?}
                             */
                            function () { return BMClickFileUploaderComponent; })),
                            multi: true,
                        },
                        UploadEventsService,
                    ],
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    // tslint:disable-next-line:use-component-view-encapsulation
                    encapsulation: ViewEncapsulation.None,
                    styles: [".bm-click-file-upload-drop-area{background:0 0;border:0;display:inline-block}"]
                }] }
    ];
    /** @nocollapse */
    BMClickFileUploaderComponent.ctorParameters = function () { return [
        { type: UploadEventsService }
    ]; };
    BMClickFileUploaderComponent.propDecorators = {
        accept: [{ type: Input }],
        dataType: [{ type: Input }],
        disabled: [{ type: Input }],
        multiple: [{ type: Input }],
        abort: [{ type: Output }],
        done: [{ type: Output }],
        empty: [{ type: Output }],
        error: [{ type: Output }],
        loading: [{ type: Output }],
        _inputElement: [{ type: ViewChild, args: ['inputFile', { read: ElementRef, static: true },] }]
    };
    return BMClickFileUploaderComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var UploadersModule = /** @class */ (function () {
    function UploadersModule() {
    }
    UploadersModule.decorators = [
        { type: NgModule, args: [{
                    imports: [CommonModule],
                    declarations: [
                        BMClickFileUploaderComponent,
                        BMFileUploaderComponent,
                        FileUploadDirective,
                        FileUploadDraggableDirective,
                    ],
                    exports: [
                        BMClickFileUploaderComponent,
                        BMFileUploaderComponent,
                        FileUploadDirective,
                        FileUploadDraggableDirective,
                    ],
                },] }
    ];
    return UploadersModule;
}());

export { BMClickFileUploaderComponent, BMFileUploaderComponent, FileUploadDirective, FileUploadDraggableDirective, UploadersModule, UploadEventsService as ɵa };
//# sourceMappingURL=bmat-angular-forms-uploaders.js.map
